% RammeSnitkraft
%---------------------------------------------------------------------
% Optegner snitkraftkurver for en to-charniersrammekonstruktion.
%---------------------------------------------------------------------
% Johan Clausen
% Institut for Byggeri og Anlg
% lborg Universitet
% April 2010
%---------------------------------------------------------------------
clear all ; % Sletter alle variable i hukommelsen

%----- Definition af laster og lngder --------------
p_e = 42.3*9.82/1000 ; % [kN/m] Egenlast, f.eks. et HE200A-profil (42.3 kg/m)
p_v1 = 1.2 ; % [kN/m] Vindlast p overliggeren imellem venstrerammehjrne og x2 = b+c
p_v2 = 3.7 ; % [kN/m] Vindlast p overliggeren imellem b+c < x2 < 2*b
P = 5 ; % [kN] Lodret enkeltkraft virkende i afstanden d fra venstre rammehjrne
a = 3 ; % [m] Rammens hjde
b = 2.6 ; % [m] Vandret afstand fra rammehjrne til punkt C, hvori charnieret er
c = 0.25*b ; % [m] Vandret afstand fra charnieret (punkt C) til spring i vindlast
d = 0.3*b ; % [m] Vandret afstand fra venstre rammehjrne til punktet hvori enkeltkraften P virker
kurvmax = 0.7*a ; % Kurvernes maksimalstrrelse. Bruges til at skale snitkraftkurverne p graferne
%----------------------------------------------------

%----- Lastkombinationskoefficienter ------------------
k_e = 0.9 ; % Faktor p egenlast
k_v = 1.5 ; % Faktor p lodret vindlast
k_p = 1.5 ; % Faktor p lodret enkeltkraft
%------------------------------------------------------

%----- Dannelse af vektorer med x-vrdier ------
n1 = 10 ; % Antal x1-vrdier
X1 = linspace(0,a,n1)' ; % X-akse med nul i venstre rammebens understtning

% Om dannelse af X2: Her skal der tages hjde for at der skal ligge et punkt i de koordinater hvor der er spring
% I dette eksempel er det ved enkeltkraften i x2 = d og ved springet i vindlast i x2 = b+c. F.eks. giver kommandoen
% linspace(0,d,10) ti punkter mellem 0 og d med det sidste punkt beliggende i d. Det nste punkt bliver placeret i en
% lille afstand fra d, nemlig i d+1e-6, som det ses i det nste interval linspace(d+1e-6,b+c,20).
X2 = [linspace(0,d,10) linspace(d+1e-6,b+c,20) linspace(b+c+1e-6,2*b,20) ]' ;
n2 = size(X2,1) ; % Antal x2-vrdier

n3 = n1 ; % Antal x3-vrdier
X3 = linspace(0,a,n3)' ; % X-akse med nul i hjre rammebens understtning
%-----------------------------------------------

%----- Beregning af Reaktioner og snitkrfter for egenlast -------------
Rav_e = (a+b)*p_e ; % [kN] Lodret reaktion i A
Rbv_e = Rav_e ; % [kN] Lodret reaktion i B
Rbh_e = -0.5*b^2/a*p_e ; % [kN] Vandret reaktion i B
Rah_e = -Rbh_e ; % [kN] Vandret reaktion i A

% Venstre Rammeben
Nvb_e = p_e*X1 - Rav_e ; % Normalkraft i venstre rammeben fra egenlast
Vvb_e = Rah_e*ones(n1,1) ; % Forskydningskraft i venstre rammeben fra egenlast
Mvb_e = -Rah_e*X1 ; % Moment i venstre rammeben fra egenlast

% Overligger
No_e = -Vvb_e(end)*ones(n2,1) ; % Normalkraft i overligger fra egenlast
Vo_e = p_e*X2 + Nvb_e(end) ; % Forskydningskraft i overligger fra egenlast
Mo_e = Mvb_e(end) - Nvb_e(end)*X2 - 0.5*p_e*X2.^2 ; % Moment i overligger fra egenlast. Bemrkt operatoren .^ som bruges nr elementer i matricer og vektorer skal oplftes i en potens

% Hjre Rammeben
Nhb_e = p_e*X3 - Rbv_e ; % Normalkraft i hjre rammeben fra egenlast
Vhb_e = -Rbh_e*ones(n3,1) ; % Forskydningskraft i hjre rammeben fra egenlast
Mhb_e = Rbh_e*X3 ; % Moment i hjre rammeben fra egenlast
%-----------------------------------------------------------------------

%----- Beregning af reaktioner og snitkrfter for lodret vindlast -------------
Rbv_v = ((b+c)^2*p_v1 + (b-c)*(3*b+c)*p_v2)/(4*b) ; % [kN] Lodret reaktion i B
Rbh_v = (-2*Rbv_v*b + c^2*p_v1 + (b^2-c^2)*p_v2)/(2*a) ; % [kN] Vandret reaktion i B
Rah_v = -Rbh_v ; % [kN] Vandret reaktion i A
Rav_v = -Rbv_v + (b+c)*p_v1 + (b-c)*p_v2 ; % [kN] Lodret reaktion i A

% Venstre Rammeben
Nvb_v = -Rav_v*ones(n1,1) ; % Normalkraft i venstre rammeben fra lodret vindlast
Vvb_v = Rah_v*ones(n1,1) ; % Forskydningskraft i venstre rammeben fra lodret vindlast
Mvb_v = -Rah_v*X1 ; % Moment i venstre rammeben fra lodret vindlast

% Overligger
index_c = find(X2<=b+c, 1, 'last') ; % Angiver det indexnummer i X2, hvor der skal skiftes til den anden vindlast. Skriv evt. help find i kommandovinduet for flere oplysninger omkring find-funktionen

No_v = -Vvb_v(end)*ones(n2,1) ; % Normalkraft i overligger fra lodret vindlast

Vo_v = zeros(n2,1) ; % Initialisering af vektor til lagring af forskydningskraft i overligger
Vo_v(1:index_c,1) = Nvb_v(end) + p_v1*X2(1:index_c) ; % Forskydningskraft i overligger fra lodret vindlast til venstre for vindlastspringet
Vo_v(index_c+1:n2,1) = Vo_v(index_c) + p_v1*(X2(index_c+1:n2)-b-c) ; % Forskydningskraft i overligger fra lodret vindlast til hjre for vindlastspringet

Mo_v = zeros(n2,1) ; % Initialisering af vektor til lagring af moment i overligger
Mo_v(1:index_c,1) = Mvb_v(end) - Nvb_v(end)*X2(1:index_c) - 0.5*p_v1*X2(1:index_c).^2 ; % Moment i overligger fra lodret vindlast til venstre for vindlastspringet
Mo_v(index_c+1:n2,1) = Mo_v(index_c) - Vo_v(index_c)*(X2(index_c+1:n2)-b-c) - 0.5*p_v2*(X2(index_c+1:n2)-b-c).^2  ; % Moment i overligger fra lodret vindlast til hjre for vindlastspringet

% Hjre Rammeben
Nhb_v = -Rbv_v*ones(n3,1) ; % Normalkraft i hjre rammeben fra lodret vindlast
Vhb_v = -Rbh_v*ones(n3,1) ; % Forskydningskraft i hjre rammeben fra lodret vindlast
Mhb_v = Rbh_v*X3 ; % Moment i hjre rammeben fra lodret vindlast
%------------------------------------------------------------------------------

%----- Beregning af reaktioner og snitkrfter for lodret enkeltkraft P -------------
Rbv_p = d/(2*b)*P ; % [kN] Lodret reaktion i B
Rbh_p = -b/a*Rbv_p ; % [kN] Vandret reaktion i B
Rah_p = -Rbh_p ; % [kN] Vandret reaktion i A
Rav_p = P - Rbv_p ; % [kN] Lodret reaktion i A

% Venstre Rammeben
Nvb_p = -Rav_p*ones(n1,1) ; % Normalkraft i venstre rammeben fra lodret enkeltkraft P
Vvb_p = Rah_p*ones(n1,1) ; % Forskydningskraft i venstre rammeben fra lodret enkeltkraft P
Mvb_p = -Rah_p*X1 ; % Moment i venstre rammeben fra lodret enkeltkraft P

% Overligger
index_d = find(X2<=d, 1, 'last') ; % Angiver det indexnummer i X2, hvor der skal skiftes til den anden vindlast. Skriv evt. help find i kommandovinduet for flere oplysninger omkring find-funktionen

No_p = -Vvb_p(end)*ones(n2,1) ; % Normalkraft i overligger fra lodret enkeltkraft P

Vo_p = zeros(n2,1) ; % Initialisering af vektor til lagring af forskydningskraft i overligger
Vo_p(1:index_d,1) = Nvb_p(end) ; % Forskydningskraft i overligger fra lodret enkeltkraft P til venstre for kraften
Vo_p(index_d+1:n2,1) = Vo_p(index_d) + P ; % Forskydningskraft i overligger fra lodret enkeltkraft P til hjre for kraften

Mo_p = zeros(n2,1) ; % Initialisering af vektor til lagring af moment i overligger
Mo_p(1:index_d,1) = Mvb_p(end) - Nvb_p(end)*X2(1:index_d) ; % Moment i overligger fra lodret enkeltkraft P til venstre for kraften
Mo_p(index_d+1:n2,1) = Mo_p(index_d) - (Vo_p(index_d) + P)*(X2(index_d+1:n2)-d) ; % Moment i overligger fra lodret enkeltkraft P til hjre for kraften

% Hjre Rammeben
Nhb_p = -Rbv_p*ones(n3,1) ; % Normalkraft i hjre rammeben fra lodret enkeltkraft P
Vhb_p = -Rbh_p*ones(n3,1) ; % Forskydningskraft i hjre rammeben fra lodret enkeltkraft P
Mhb_p = Rbh_p*X3 ; % Moment i hjre rammeben fra lodret enkeltkraft P
%-----------------------------------------------------------------------------------

%----- Dannelse af lastkombination -----------------------------
% Venstre ben
Nvb_kombi = k_e*Nvb_e + k_v*Nvb_v + k_p*Nvb_p ;
Vvb_kombi = k_e*Vvb_e + k_v*Vvb_v + k_p*Vvb_p ;
Mvb_kombi = k_e*Mvb_e + k_v*Mvb_v + k_p*Mvb_p ;

% Overligger
No_kombi = k_e*No_e + k_v*No_v + k_p*No_p ;
Vo_kombi = k_e*Vo_e + k_v*Vo_v + k_p*Vo_p ;
Mo_kombi = k_e*Mo_e + k_v*Mo_v + k_p*Mo_p ;

% Overligger
Nhb_kombi = k_e*Nhb_e + k_v*Nhb_v + k_p*Nhb_p ;
Vhb_kombi = k_e*Vhb_e + k_v*Vhb_v + k_p*Vhb_p ;
Mhb_kombi = k_e*Mhb_e + k_v*Mhb_v + k_p*Mhb_p ;

%--------------------------------------------------------------------------------
%----- Plotning -----------------------------------------------------------------
%--------------------------------------------------------------------------------

%----- Snitkraftkurver fra egenlast -----------------
figure(1) ; clf ; hold on
plotNVM_ramme(a,b,X1,Nvb_e,Vvb_e,Mvb_e,X2,No_e,Vo_e,Mo_e,X3,Nhb_e,Vhb_e,Mhb_e,kurvmax,'Snitkrfter fra egenlast')
%----------------------------------------------------

%----- Snitkraftkurver fra lodret vindlast -----------------
figure(2) ; clf ; hold on
plotNVM_ramme(a,b,X1,Nvb_v,Vvb_v,Mvb_v,X2,No_v,Vo_v,Mo_v,X3,Nhb_v,Vhb_v,Mhb_v,kurvmax,'Snitkrfter fra lodret vindlast')
%-----------------------------------------------------------

%----- Snitkraftkurver fra lodret enkeltkraft --------
figure(3) ; clf ; hold on
plotNVM_ramme(a,b,X1,Nvb_p,Vvb_p,Mvb_p,X2,No_p,Vo_p,Mo_p,X3,Nhb_p,Vhb_p,Mhb_p,kurvmax,'Snitkrfter fra lodret enkeltkraft, \it{P}')
%-----------------------------------------------------

%----- Snitkraftkurver for lastkombination --------
figure(4) ; clf ; hold on
plotNVM_ramme(a,b,X1,Nvb_kombi,Vvb_kombi,Mvb_kombi,X2,No_kombi,Vo_kombi,Mo_kombi,X3,Nhb_kombi,Vhb_kombi,Mhb_kombi,kurvmax,...
			['Snitkrfter lastkombination med {\itk_e} = ',num2str(k_e),', {\itk_v} = ',num2str(k_v),' og {\itk_p} = ',num2str(k_p)]) ;
%--------------------------------------------------

%----- Slut ----------------------------------------------------------------